# -*- coding: utf-8 -*-
#
# Trespasser Blender Scripts
#
# Copyright (C) 2011, Plüss Roland ( roland@rptd.ch )
# 
# This program is free software; you can redistribute it and/or 
# modify it under the terms of the GNU General Public License 
# as published by the Free Software Foundation; either 
# version 2 of the License, or (at your option) any later 
# version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
# NOTE: For the GPL copy see http://www.gnu.org/licenses/gpl.html
#

bl_info = {
	"name": "Trespasser Resources",
	"description": "Import/Export Trespasser Resources",
	"author": "Plüss Roland",
	"version": (1, 0),
	"blender": (2, 5, 7),
	"api": 36079,
	"location": "File > Import-Export > Trespasser Resources",
	"warning": "",
	"url": "http://trespasser.rptd.ch",
	"category": "Import-Export"
	}

if "bpy" in locals():
	import imp
	if "tp_math" in locals():
		imp.reload( tp_math )
	if "tp_resources" in locals():
		imp.reload( tp_resources )
	if "tp_tools" in locals():
		imp.reload( tp_tools )
	if "tp_export_tpm" in locals():
		imp.reload( tp_export_tpm )
	if "tp_export_valuestxt" in locals():
		imp.reload( tp_export_valuestxt )

from . import tp_tools
from .tp_export_tpm import OBJECT_OT_ExportTPM
from .tp_export_valuestxt import OBJECT_OT_ExportValuesTXT

import bpy
import os
import re
import math
import time
import struct
import mathutils

from bpy_extras.io_utils import ExportHelper
from mathutils import Vector, Matrix



class VIEW3D_MT_TPRes( bpy.types.Menu ):
	bl_label = "Trespasser Resources"
	
	def draw( self, context ):
		layout = self.layout
		settings = context.tool_settings
		layout.operator_context = 'INVOKE_REGION_WIN'
		layout.operator( "trespasser.export_tpm", text=OBJECT_OT_ExportTPM.bl_label )
		layout.operator( "trespasser.export_valuestxt", text=OBJECT_OT_ExportValuesTXT.bl_label )

def menu_func( self, context ):
	self.layout.menu( "VIEW3D_MT_TPRes" )

def register():
	bpy.utils.register_module( __name__ )
	bpy.types.INFO_MT_file_export.append( menu_func )

def unregister():
	bpy.utils.unregister_module( __name__ )
	bpy.types.INFO_MT_file_export.remove( menu_func )

if __name__ == "__main__":
	register()
