# -*- coding: utf-8 -*-
#
# Drag[en]gine Blender Scripts
#
# Copyright (C) 2011, Plüss Roland ( roland@rptd.ch )
# 
# This program is free software; you can redistribute it and/or 
# modify it under the terms of the GNU General Public License 
# as published by the Free Software Foundation; either 
# version 2 of the License, or (at your option) any later 
# version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
# NOTE: For the GPL copy see http://www.gnu.org/licenses/gpl.html
#

import bpy
import math
import time
import struct
import mathutils

from mathutils import Vector, Matrix

# constants
PI = 3.14159265
HALF_PI = PI / 2.0
ONE_PI = PI / 180.0

transformPosition = Matrix( ( (-1,0,0,0), (0,-1,0,0), (0,0,1,0), (0,0,0,0) ) )



# Math classes
################

# helper function to convert matrix from blender to trespasser matrix
def convertMatrix( matrix ):
	axisX = ( -matrix[0][0], -matrix[0][1], matrix[0][2], 0 )
	axisY = ( -matrix[1][0], -matrix[1][1], matrix[1][2], 0 )
	axisZ = ( -matrix[2][0], -matrix[2][1], matrix[2][2], 0 )
	pos = ( -matrix[3][0], -matrix[3][1], matrix[3][2], 1 )
	return Matrix( ( axisX, axisZ, axisY, pos ) )

def convertEuler( euler ):
	"""
	matrix = euler.to_matrix()
	axisX = ( matrix[0][0], -matrix[0][1], matrix[0][2] )
	axisY = ( matrix[1][0], -matrix[1][1], matrix[1][2] )
	axisZ = ( -matrix[2][0], matrix[2][1], -matrix[2][2] )
	return matrixToEuler( Matrix( ( axisX, axisZ, axisY ) ) )
	"""
	euler = euler.to_matrix().to_euler()
	return Vector( [ euler.x / ONE_PI, euler.y / ONE_PI, euler.z / ONE_PI ] )

# create a trespasser rotation matrix
def deRotationMatrix( r ):
	a = math.sin( r[0] * ONE_PI )
	b = math.cos( r[0] * ONE_PI )
	c = math.sin( r[1] * ONE_PI )
	d = math.cos( r[1] * ONE_PI )
	e = math.sin( r[2] * ONE_PI )
	f = math.cos( r[2] * ONE_PI )
	g = d * f
	h = c * f
	i = c * e
	j = d * e
	#axisX = Vector( [ g-a*i, a*h+j, -c*b, 0 ] )
	#axisY = Vector( [ -b*e, b*f, a, 0 ] )
	#axisZ = Vector( [ h+a*j, -a*g+i, b*d, 0 ] )
	axisX = ( g-a*i, -b*e, h+a*j, 0.0 )
	axisY = ( a*h+j, b*f, -a*g+i, 0.0 )
	axisZ = ( -c*b, a, b*d, 0.0 )
	return Matrix( ( axisX, axisY, axisZ, ( 0.0, 0.0, 0.0, 1.0 ) ) )

# helper function calculating the euler angles from a given converted matrix
def matrixToEuler( matrix ):
	euler = Vector( [ 0.0, 0.0, 0.0 ] )
	
	if matrix[2][1] < 1.0:
		if matrix[2][1] > -1.0:
			euler = Vector( [ math.asin( matrix[2][1] ), math.atan2( -matrix[2][0], matrix[2][2] ), math.atan2( -matrix[0][1], matrix[1][1] ) ] )
			
		else: # undefined
			euler = Vector( [ -PI * 0.5, 0.0, -math.atan2( matrix[0][2], matrix[0][0] ) ] )
		
	else: # undefined
		euler = Vector( [ PI * 0.5, 0.0, math.atan2( matrix[0][2], matrix[0][0] ) ] )
	
	return Vector( [ euler.x / ONE_PI, euler.y / ONE_PI, euler.z / ONE_PI ] )

# helper function to transform a vector by a matrix
def vector_by_matrix( m, p ):
  return Vector( ( p[0] * m[0][0] + p[1] * m[1][0] + p[2] * m[2][0] + m[3][0],
          p[0] * m[0][1] + p[1] * m[1][1] + p[2] * m[2][1] + m[3][1],
          p[0] * m[0][2] + p[1] * m[1][2] + p[2] * m[2][2] + m[3][2] ) )

# helper function to transform an axis vector by a matrix
def axis_by_matrix( m, p ):
  return Vector( ( p[0] * m[0][0] + p[1] * m[1][0] + p[2] * m[2][0],
          p[0] * m[0][1] + p[1] * m[1][1] + p[2] * m[2][1],
          p[0] * m[0][2] + p[1] * m[1][2] + p[2] * m[2][2] ) )
