# -*- coding: utf-8 -*-
#
# Trespasser Blender Scripts
#
# Copyright (C) 2011, Plüss Roland ( roland@rptd.ch )
# 
# This program is free software; you can redistribute it and/or 
# modify it under the terms of the GNU General Public License 
# as published by the Free Software Foundation; either 
# version 2 of the License, or (at your option) any later 
# version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
# NOTE: For the GPL copy see http://www.gnu.org/licenses/gpl.html
#

import bpy
import os
import re
import math
import time
import struct
import mathutils

from mathutils import Vector, Matrix



# Properties
##############
"""
class VIEW3D_PT_Trespasser( bpy.types.Panel ):
	bl_space_type = 'VIEW_3D'
	bl_region_type = 'TOOLS'
	bl_label = "Trespasser Tools"
	
	@classmethod
	def poll( cls, context ):
		return context.active_object
	
	def draw( self, context ):
		layout = self.layout
		layout.prop( context.scene, "trespasser_scaling", expand = True )
		if context.active_object.type == 'MESH':
			self.drawMeshTools( context.active_object )
	
	def drawMeshTools( self, object ):
		layout = self.layout
"""


bpy.types.Scene.trespasser_scaling = bpy.props.FloatProperty(
	name="Scaling", description="Global scaling to apply", default=1.0, min=0.0, max=1.0 )

class OBJECT_PT_SceneGlobal( bpy.types.Panel ):
	bl_space_type = 'PROPERTIES'
	bl_region_type = 'WINDOW'
	bl_context = "scene"
	bl_label = "Trespasser"
	
	def draw( self, context ):
		layout = self.layout
		rd = context.scene
		layout.prop( rd, "trespasser_scaling", expand=True )



bpy.types.Object.trespasser_scaling = bpy.props.FloatProperty(
	name="Scaling", description="Scaling to apply",
	default=1.0, min=0.0, max=1.0 )

bpy.types.Object.trespasser_meshtype = bpy.props.EnumProperty( items = (
	( 'MESH', "Basic", "Basic mesh" ),
	( 'PHYSICS', "Physics", "Physics mesh" ),
	( 'INVISIBLE', "Invisible", "Invisible mesh" ),
	( 'MAGNET', "Magnet", "Magnet mesh" ),
	( 'TRIGGER', "Trigger", "Trigger mesh" ),
	( 'EFFECT', "Effect", "Effect mesh" ),
	( 'VOCAL', "Vocal", "Vocal mesh" ),
	), name = "Mesh Type", description = "Type of mesh used during tpm.values.txt export to write default TScripts", default = 'MESH' )

bpy.types.Object.trespasser_moveable = bpy.props.BoolProperty(
	name="Moveable", description="Determines if the mesh is moveable", default=False )

bpy.types.Object.trespasser_tangible = bpy.props.BoolProperty(
	name="Tangible", description="Determines if the mesh is tangible", default=True )

bpy.types.Object.trespasser_soundmaterial = bpy.props.StringProperty(
	name="Sound Material", description="Sound to play for impact", default="Wood Hard 1" )

bpy.types.Object.trespasser_density = bpy.props.FloatProperty(
	name="Density", description="Density for physics simulation", default=0.5 )

class OBJECT_PT_Object( bpy.types.Panel ):
	bl_space_type = 'PROPERTIES'
	bl_region_type = 'WINDOW'
	bl_context = "object"
	bl_label = "Trespasser"
	
	def draw( self, context ):
		layout = self.layout
		rd = context.active_object
		layout.prop( rd, "trespasser_scaling", expand = True )
		layout.prop( rd, "trespasser_meshtype", expand = False )
		row = layout.row( True )
		row.prop( rd, "trespasser_moveable", expand = True )
		row.prop( rd, "trespasser_tangible", expand = True )
		layout.prop( rd, "trespasser_soundmaterial", expand = True )
		layout.prop( rd, "trespasser_density", expand = True )



bpy.types.Material.trespasser_exportname = bpy.props.StringProperty(
	name="Export Name", description="Export name to use for the material. Use empty string to use the blender material name.", default="" )

bpy.types.Material.trespasser_bitmapname = bpy.props.StringProperty(
	name="Bitmap Name", description="Name to use as the bitmap", default="material.bmp" )

class OBJECT_PT_Material( bpy.types.Panel ):
	bl_space_type = 'PROPERTIES'
	bl_region_type = 'WINDOW'
	bl_context = "material"
	bl_label = "Trespasser"
	
	def draw( self, context ):
		layout = self.layout
		if context.active_object and context.active_object.active_material and context.active_object.type == 'MESH':
			rd = context.active_object.active_material
			layout.prop( rd, "trespasser_bitmapname", expand = True )
			layout.prop( rd, "trespasser_exportname", expand = True )
